.. currentmodule:: pdcast

.. _complex_types:

Complex
=======

Generic
-------

.. _complex_type:

.. autoclass:: ComplexType

.. _complex64_type:

.. autoclass:: Complex64Type

.. _complex128_type:

.. autoclass:: Complex128Type

.. _complex160_type:

.. autoclass:: Complex160Type

Numpy
-----

.. _numpy_complex_type:

.. autoclass:: NumpyComplexType

.. _numpy_complex64_type:

.. autoclass:: NumpyComplex64Type

.. _numpy_complex128_type:

.. autoclass:: NumpyComplex128Type

.. _numpy_complex160_type:

.. autoclass:: NumpyComplex160Type

Python
------

.. _python_complex_type:

.. autoclass:: PythonComplexType
